
# Type: float


A real number that conforms to the xsd:float specification

URI: [https://example.com/test62/meta:types/Float](https://example.com/test62/meta:types/Float)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **float** |
